@@ -6,6 +6,7 @@ from .utils.weld import weld_datapack, weld_resource_pack
 from .utils.archive import make_archive
 from .datapack.lang import main as lang_main
 from .datapack.headers import main as headers_main
+from .datapack.basic_structure import main as basic_structure_main
 from .datapack.custom_block_ticks import custom_blocks_ticks_and_second_functions
 from .resource_pack.check_unused_textures import main as check_unused_textures_main
 from .dependencies.main import main as dependencies_main, OFFICIAL_LIBS_PATH, OFFICIAL_LIBS
@@ -14,45 +15,47 @@ import shutil
 def main(config: dict, user_code: callable):
 
 	# Copy original_icon.png to pack.png if it exists
-	if os.path.exists(f"{config['assets_folder']}/original_icon.png"):
-		super_copy(f"{config['assets_folder']}/original_icon.png", f"{config['build_resource_pack']}/pack.png")
+	if config.get('assets_folder') and os.path.exists(f"{config['assets_folder']}/original_icon.png"):
 		super_copy(f"{config['assets_folder']}/original_icon.png", f"{config['build_datapack']}/pack.png")
+		if config.get('resource_pack_format'):
+			super_copy(f"{config['assets_folder']}/original_icon.png", f"{config['build_resource_pack']}/pack.png")
 
 	# For every file in the merge folder, copy it to the build folder (with append content)
-	print()
-	start_time: float = time.perf_counter()
-	for root, _, files in os.walk(config['merge_folder']):
-		for file in files:
-			merge_path = f"{root}/{file}".replace("\\", "/")
-			build_path = merge_path.replace(config['merge_folder'], config['build_folder'])
-			
-			# Append content to the build file is any
-			if FILES_TO_WRITE.get(build_path):
-
-				# If file is not JSON format,
-				if not file.endswith(".json"):
-					with super_open(merge_path, "r") as f:
-						write_to_file(build_path, f.read())
-
-				else:
-					# Load to two dictionnaries
-					with super_open(merge_path, "r") as f:
-						merge_dict = json.load(f)
-					build_dict = json.loads(FILES_TO_WRITE[build_path])
-					
-					# Write the merged dictionnaries to the build file
-					FILES_TO_WRITE[build_path] = super_json_dump(super_merge_dict(build_dict, merge_dict), max_level = -1)
-			else:
-				# Get content of .mcfunction file to correctly append headers
-				if file.endswith((".json",".mcfunction")):
-					with super_open(merge_path, "r") as f:
-						write_to_file(build_path, f.read())
+	if config.get('merge_folder'):
+		print()
+		start_time: float = time.perf_counter()
+		for root, _, files in os.walk(config['merge_folder']):
+			for file in files:
+				merge_path = f"{root}/{file}".replace("\\", "/")
+				build_path = merge_path.replace(config['merge_folder'], config['build_folder'])
 				
-				# Else, just copy the file, such as pack.mcmeta, pack.png, ...
+				# Append content to the build file is any
+				if FILES_TO_WRITE.get(build_path):
+
+					# If file is not JSON format,
+					if not file.endswith(".json") and not file.endswith(".mcmeta"):
+						with super_open(merge_path, "r") as f:
+							write_to_file(build_path, f.read())
+
+					else:
+						# Load to two dictionnaries
+						with super_open(merge_path, "r") as f:
+							merge_dict = json.load(f)
+						build_dict = json.loads(FILES_TO_WRITE[build_path])
+						
+						# Write the merged dictionnaries to the build file
+						FILES_TO_WRITE[build_path] = super_json_dump(super_merge_dict(build_dict, merge_dict), max_level = -1)
 				else:
-					super_copy(merge_path, build_path)
-	total_time: float = time.perf_counter() - start_time
-	info(f"All content in the '{config['merge_folder']}' folder copied to '{config['build_folder']}' in {total_time:.5f}s")
+					# Get content of .mcfunction file to correctly append headers
+					if file.endswith((".json",".mcfunction",".mcmeta")):
+						with super_open(merge_path, "r") as f:
+							write_to_file(build_path, f.read())
+					
+					# Else, just copy the file, such as pack.mcmeta, pack.png, ...
+					else:
+						super_copy(merge_path, build_path)
+		total_time: float = time.perf_counter() - start_time
+		info(f"All content in the '{config['merge_folder']}' folder copied to '{config['build_folder']}' in {total_time:.5f}s")
 
 	# Run user code
 	if user_code:
@@ -64,11 +67,14 @@ def main(config: dict, user_code: callable):
 	# Second and tick functions for custom blocks
 	custom_blocks_ticks_and_second_functions(config)
 
+	# Generate basic datapack structure (tick, tick_2, second, second_5, minute) if needed
+	basic_structure_main(config)
+
 	# Check for official libs uses
 	dependencies_main(config)
 
 	# Generate lang file
-	if config['enable_translations']:
+	if config.get('enable_translations') == True:
 		lang_main(config)
 
 	# Add a small header for each .mcfunction file
@@ -81,32 +87,32 @@ def main(config: dict, user_code: callable):
 	info(f"All pending files written in {total_time:.5f}s")
 
 	# Check not used textures
-	check_unused_textures_main(config)
+	if config.get('textures_folder'):
+		check_unused_textures_main(config)
 
 
 	# Generate zip files
-	datapack_dest: str = config['build_copy_destinations'][0]
-	resourcepack_dest: str = config['build_copy_destinations'][1]
+	datapack_dest: list[str] = config['build_copy_destinations'][0] if config.get('build_copy_destinations') else []
+	resourcepack_dest: list[str] = config['build_copy_destinations'][1] if config.get('build_copy_destinations') and len(config['build_copy_destinations']) > 1 else []
 	processes = [
-		(config['build_datapack'], f"{config['build_folder']}/{config['datapack_name_simple']}_datapack", datapack_dest),
-		(config['build_resource_pack'], f"{config['build_folder']}/{config['datapack_name_simple']}_resource_pack", resourcepack_dest)
+		(config['build_datapack'],			f"{config['build_folder']}/{config['datapack_name_simple']}_datapack",			datapack_dest),
+		(config['build_resource_pack'],		f"{config['build_folder']}/{config['datapack_name_simple']}_resource_pack",		resourcepack_dest)
 	]
 	for source, destination, copy_destinations in processes:
 		if os.path.exists(source):
 			total_time: float = make_archive(source, destination, copy_destinations)
 			debug(f"'{destination}.zip' file generated and copied to destinations in {total_time:.5f}s")
-		else:
-			warning(f"No '{source}' folder, skipping")
 
 	# Copy datapack libraries
 	try:
 		
 		# Copy lib folder
-		for root, _, files in os.walk(config['libs_folder'] + "/datapack"):
-			for file in files:
-				if file.endswith(".zip"):
-					shutil.copy(f"{root}/{file}", datapack_dest)
-					info(f"Library '{file}' copied to '{datapack_dest}/'")
+		if config.get('libs_folder'):
+			for root, _, files in os.walk(config['libs_folder'] + "/datapack"):
+				for file in files:
+					if file.endswith(".zip"):
+						shutil.copy(f"{root}/{file}", datapack_dest)
+						info(f"Library '{file}' copied to '{datapack_dest}/'")
 		
 		# Copy official used libs
 		for data in OFFICIAL_LIBS.values():
@@ -120,7 +126,7 @@ def main(config: dict, user_code: callable):
 
 
 	# If merge libs is enabled, use weld to generate datapack and resource pack with bundled libraries
-	if config['merge_libs']:
+	if config.get('merge_libs') == True:
 
 		# Merge weld dp
 		weld_dp: str = f"{config['build_folder']}/{config['datapack_name_simple']}_datapack_with_libs.zip"
