@@ -6,6 +6,7 @@ from .utils.print import *
 from .utils.io import *
 
 def main(config: dict):
+	start_time: float = time.perf_counter()
 
 	# Export database to JSON for debugging generation
 	with super_open(config['database_debug'], "w") as f:
@@ -26,8 +27,13 @@ def main(config: dict):
 				errors.append(f"'id' key should not be 'minecraft:deepslate' for '{item}', it's a reserved ID")
 			
 			# Force VANILLA_BLOCK key for custom blocks
-			elif data["id"] in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE] and not data.get(VANILLA_BLOCK):
-				errors.append(f"VANILLA_BLOCK key missing for '{item}', needed format: VANILLA_BLOCK: \"minecraft:stone\"")
+			elif data["id"] in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE]:
+				if not data.get(VANILLA_BLOCK):
+					errors.append(f"VANILLA_BLOCK key missing for '{item}', needed format: VANILLA_BLOCK: {{\"id\":\"minecraft:stone\", \"apply_facing\":False}}.")
+				elif not isinstance(data[VANILLA_BLOCK], dict):
+					errors.append(f"VANILLA_BLOCK key should be a dictionary for '{item}', found '{data[VANILLA_BLOCK]}', needed format: VANILLA_BLOCK: {{\"id\":\"minecraft:stone\", \"apply_facing\":False}}.")
+				elif data[VANILLA_BLOCK].get("apply_facing", None) == None:
+					errors.append(f"VANILLA_BLOCK key should have a 'apply_facing' key to boolean for '{item}', found '{data[VANILLA_BLOCK]}', needed format: VANILLA_BLOCK: {{\"id\":\"minecraft:stone\", \"apply_facing\":False}}.")
 
 			# Prevent the use of "container" key for custom blocks
 			elif data["id"] == CUSTOM_BLOCK_VANILLA and data.get("container"):
@@ -141,7 +147,7 @@ def main(config: dict):
 
 		# Commands on custom block placement
 		if data.get(COMMANDS_ON_PLACEMENT) and data.get("id"):
-			if data["id"] not in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE]:
+			if data["id"] not in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE, CUSTOM_BLOCK_HEAD]:
 				errors.append(f"COMMANDS_ON_PLACEMENT key should only be used for custom blocks for '{item}'")
 			elif not isinstance(data[COMMANDS_ON_PLACEMENT], (list, str)):
 				errors.append(f"COMMANDS_ON_PLACEMENT key should be a list of string or a string for '{item}'")
@@ -152,7 +158,7 @@ def main(config: dict):
 		
 		# Commands on custom block break
 		if data.get(COMMANDS_ON_BREAK) and data.get("id"):
-			if data["id"] not in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE]:
+			if data["id"] not in [CUSTOM_BLOCK_VANILLA, CUSTOM_BLOCK_ALTERNATIVE, CUSTOM_BLOCK_HEAD]:
 				errors.append(f"COMMANDS_ON_BREAK key should only be used for custom blocks for '{item}'")
 			elif not isinstance(data[COMMANDS_ON_BREAK], (list, str)):
 				errors.append(f"COMMANDS_ON_BREAK key should be a list of string or a string for '{item}'")
@@ -166,7 +172,8 @@ def main(config: dict):
 	if errors:
 		error("Errors found in the database during verification:\n" + "\n".join(errors))
 	else:
-		info("No errors found in the database during verification")
+		total_time = time.perf_counter() - start_time
+		info(f"No errors found in the database during verification (took {total_time:.5f}s)")
 
 
 	# Add additional data to the custom blocks
